@@ -18,7 +18,7 @@ class SearchRSS(object):
 
     schema = {'$ref': '/schema/plugin/rss'}
 
-    def search(self, entry, config=None):
+    def search(self, task, entry, config=None):
         from flexget.utils.template import environment
         from flexget.manager import manager
         search_strings = [urllib.quote(normalize_unicode(s).encode('utf-8'))
@@ -32,8 +32,6 @@ class SearchRSS(object):
             raise plugin.PluginError('Invalid jinja template as rss url: %s' % e)
         rss_config['all_entries'] = True
         for search_string in search_strings:
-            # Create a fake task to pass to the rss plugin input handler
-            task = Task(manager, 'search_rss_task', config={})
             rss_config['url'] = template.render({'search_term': search_string})
             # TODO: capture some other_fields to try to find seed/peer/content_size numbers?
             try:
